# Python Script: menusys

### Written By: Benjamin P. Trachtenberg
### If you have any questions e-mail me

### Contact Information:  e_ben_75-python@yahoo.com

### LinkedIn: [Ben Trachtenberg](https://www.linkedin.com/in/ben-trachtenberg-3a78496)
### Docker Hub: [Docker Hub](https://hub.docker.com/r/btr1975)
### PyPi Page for [menusys](https://pypi.python.org/pypi/menusys)

### Requirements

* Nothing Specific besides Python 3.5 and above

### Installation

* From source "setup.py install"
* From pip "pip install menusys"

### Languages

* Python

### About

This is a library used to have a CLI menu system.

### Functions included in v1.0.0

* menu(menu_dictionary, menu_header, back_function=None)
* clear_screen()

### Functions added in v1.0.2

* menu_multi_select(menu_dictionary, menu_header, back_function=None)

### Functions added in v1.0.3

* make_menu_dict_from_dict(orig_dict, dict_key_for_display)

### Functions added in v1.0.4

* make_menu_dict_from_list(orig_list)

### Functions added in v1.1.1
* word_wrap_string_and_print(string_to_wrap)
* chunk_up_string(string_to_chunk, size_of_chunk=100)

### Functions added in v1.1.2
* word_wrap_string(string_to_wrap)
